@@ -4,9 +4,8 @@
 #include <unistd.h>
 
 off_t
-_DEFUN (lseek, (fd, pos, whence),
-     int fd _AND
-     off_t pos _AND
+lseek (int fd,
+     off_t pos,
      int whence)
 {
   return _lseek_r (_REENT, fd, pos, whence);
